pub enum RegisterResourceErrorKind {
UnsupportedResourceKind,
Other,
Unimplemented,
NotActive,
}Variants
UnsupportedResourceKind
The RenderContext you tried to register the resource with does not support the kind of resource
Other
Some other kind of error occured
Unimplemented
This backend has not implemented resource registration
NotActive
The RenderContext you tried to register the resource is not currently active