pub struct SpotLightSource {
pub x: f32,
pub y: f32,
pub z: f32,
pub points_at_x: f32,
pub points_at_y: f32,
pub points_at_z: f32,
pub specular_exponent: f32,
pub limiting_cone_angle: Option<f32>,
}Expand description
Spot light with position, direction, and cone angle.
Light emanates from a point in a specific direction with limited spread. Like a flashlight or stage spotlight with adjustable focus.
Fields
x: f32y: f32z: f32points_at_x: f32points_at_y: f32points_at_z: f32specular_exponent: f32limiting_cone_angle: Option<f32>Trait Implementations
Sourceimpl Clone for SpotLightSource
impl Clone for SpotLightSource
Sourcefn clone(&self) -> SpotLightSource
fn clone(&self) -> SpotLightSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpotLightSource
impl Debug for SpotLightSource
Sourceimpl PartialEq for SpotLightSource
impl PartialEq for SpotLightSource
impl StructuralPartialEq for SpotLightSource