pub struct DropShadow {
pub dx: f32,
pub dy: f32,
pub std_deviation: f32,
pub color: AlphaColor<Srgb>,
pub edge_mode: EdgeMode,
}Expand description
Drop shadow effect (compound primitive).
Creates a drop shadow by blurring the input’s alpha channel, offsetting it, and compositing it with the original. This is a compound operation that combines multiple primitive operations into one.
See: https://drafts.fxtf.org/filter-effects-2/#feDropShadowElement
Fields
dx: f32dy: f32std_deviation: f32color: AlphaColor<Srgb>edge_mode: EdgeModeTrait Implementations
Sourceimpl Clone for DropShadow
impl Clone for DropShadow
Sourcefn clone(&self) -> DropShadow
fn clone(&self) -> DropShadow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DropShadow
impl Debug for DropShadow
Sourceimpl PartialEq for DropShadow
impl PartialEq for DropShadow
impl StructuralPartialEq for DropShadow