Module recording

Module recording 

Structs

BoxShadowCommand
Draw a box shadow around a box
ClipCommand
Pushes a new clip layer clipped by the specified shape. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.
FillCommand
Fills a shape using the specified style and brush.
GlyphRunCommand
Draws a run of glyphs
LayerCommand
Pushes a new layer clipped by the specified shape and composed with previous layers using the specified blend mode. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.
Scene
A recording of a Scene or Scene Fragment stored as plain data types that can be stored and passed around.
StrokeCommand
Strokes a shape using the specified style and brush.

Enums

RenderCommand