ClipCommand

Struct ClipCommand 

pub struct ClipCommand {
    pub transform: Affine,
    pub clip: BezPath,
}
Pushes a new clip layer clipped by the specified shape. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.

Fields

transform: Affineclip: BezPath