LayerCommand

Struct LayerCommand 

pub struct LayerCommand {
    pub blend: BlendMode,
    pub alpha: f32,
    pub transform: Affine,
    pub clip: BezPath,
    pub filter: Option<Arc<Filter>>,
    pub backdrop_filter: Option<Arc<Filter>>,
}
Pushes a new layer clipped by the specified shape and composed with previous layers using the specified blend mode. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.

Fields

blend: BlendModealpha: f32transform: Affineclip: BezPathfilter: Option<Arc<Filter>>backdrop_filter: Option<Arc<Filter>>