pub struct Scene {
pub tolerance: f64,
pub commands: Vec<RenderCommand>,
}Expand description
A recording of a Scene or Scene Fragment stored as plain data types that can be stored and passed around.
Fields
tolerance: f64commands: Vec<RenderCommand>Implementations