DropShadow

Struct DropShadow 

pub struct DropShadow {
    pub dx: f32,
    pub dy: f32,
    pub std_deviation: f32,
    pub color: AlphaColor<Srgb>,
    pub edge_mode: EdgeMode,
}
Drop shadow effect (compound primitive).

Creates a drop shadow by blurring the input’s alpha channel, offsetting it, and compositing it with the original. This is a compound operation that combines multiple primitive operations into one.

See: https://drafts.fxtf.org/filter-effects-2/#feDropShadowElement

Fields

dx: f32dy: f32std_deviation: f32color: AlphaColor<Srgb>edge_mode: EdgeMode