RenderCommand

Enum RenderCommand 

pub enum RenderCommand<Font = FontData, Brush = Paint> {
    PushLayer(LayerCommand),
    PushClipLayer(ClipCommand),
    PopLayer,
    Stroke(StrokeCommand<Brush>),
    Fill(FillCommand<Brush>),
    GlyphRun(GlyphRunCommand<Font, Brush>),
    BoxShadow(BoxShadowCommand),
}

Variants



PushLayer(LayerCommand)

Pushes a new layer clipped by the specified shape and composed with previous layers using the specified blend mode. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.



PushClipLayer(ClipCommand)

Pushes a new clip layer clipped by the specified shape. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.



PopLayer

Pops the current layer.



Stroke(StrokeCommand<Brush>)

Strokes a shape using the specified style and brush.



Fill(FillCommand<Brush>)

Fills a shape using the specified style and brush.



GlyphRun(GlyphRunCommand<Font, Brush>)

Draws a run of glyphs



BoxShadow(BoxShadowCommand)

Draw a rounded rectangle blurred with a gaussian filter.