pub struct ClipCommand {
pub transform: Affine,
pub clip: BezPath,
}Expand description
Pushes a new clip layer clipped by the specified shape. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.
Fields
transform: Affineclip: BezPathTrait Implementations
Sourceimpl Clone for ClipCommand
impl Clone for ClipCommand
Sourcefn clone(&self) -> ClipCommand
fn clone(&self) -> ClipCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClipCommand
impl Debug for ClipCommand
Sourceimpl PartialEq for ClipCommand
impl PartialEq for ClipCommand
impl StructuralPartialEq for ClipCommand