pub struct LayerCommand {
pub blend: BlendMode,
pub alpha: f32,
pub transform: Affine,
pub clip: BezPath,
pub filter: Option<Arc<Filter>>,
pub backdrop_filter: Option<Arc<Filter>>,
}Expand description
Pushes a new layer clipped by the specified shape and composed with previous layers using the specified blend mode. Every drawing command after this call will be clipped by the shape until the layer is popped. However, the transforms are not saved or modified by the layer stack.
Fields
blend: BlendModealpha: f32transform: Affineclip: BezPathfilter: Option<Arc<Filter>>backdrop_filter: Option<Arc<Filter>>Trait Implementations
Sourceimpl Clone for LayerCommand
impl Clone for LayerCommand
Sourcefn clone(&self) -> LayerCommand
fn clone(&self) -> LayerCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LayerCommand
impl Debug for LayerCommand
Sourceimpl PartialEq for LayerCommand
impl PartialEq for LayerCommand
impl StructuralPartialEq for LayerCommand