Scene

Struct Scene 

pub struct Scene {
    pub tolerance: f64,
    pub commands: Vec<RenderCommand>,
}
A recording of a Scene or Scene Fragment stored as plain data types that can be stored and passed around.

Fields

tolerance: f64commands: Vec<RenderCommand>

Implementations

Source

impl Scene

pub fn new() -> Self

Create a new empty

pub fn with_tolerance(tolerance: f64) -> Self